# OpenDR Pose Estimation - Lightweight Open Pose

This folder contains the OpenDR Learner and Target classes implemented for the pose estimation task. 

## Sources

Large parts of the Learner and utilities.py code are taken from [Daniil-Osokin/lightweight-human-pose-estimation.pytorch](
https://github.com/Daniil-Osokin/lightweight-human-pose-estimation.pytorch) with modifications to make them compatible 
with OpenDR specifications.
